"use client"

import type React from "react"
import { useState, useEffect } from "react"
import { useSearchParams } from "next/navigation"
import Link from "next/link"
import { FileText, Upload, CheckCircle, Loader2, ArrowLeft } from "lucide-react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { useWalletStore } from "@/lib/wallet-store"
import { Badge } from "@/components/ui/badge"
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert"

// Mock issues data for the dropdown
const mockIssues = [
  {
    id: "climate-action",
    title: "Climate Action Policies",
    category: "Environmental Policy"
  },
  {
    id: "education-reform",
    title: "Education System Reform",
    category: "Education"
  },
  {
    id: "healthcare-access",
    title: "Healthcare Accessibility",
    category: "Healthcare"
  },
  {
    id: "housing-affordability",
    title: "Housing Affordability Crisis",
    category: "Infrastructure"
  },
  {
    id: "digital-privacy",
    title: "Digital Privacy Regulations",
    category: "Technology"
  }
]

export default function SubmitPage() {
  const { walletConnected } = useWalletStore()
  const searchParams = useSearchParams()
  const issueParam = searchParams.get('issue')

  const [isSubmitting, setIsSubmitting] = useState(false)
  const [isSubmitted, setIsSubmitted] = useState(false)
  const [ipfsHash, setIpfsHash] = useState("")
  const [selectedIssue, setSelectedIssue] = useState<string | null>(null)
  const [title, setTitle] = useState("")
  const [content, setContent] = useState("")

  // Set the selected issue from URL parameter if available
  useEffect(() => {
    if (issueParam) {
      setSelectedIssue(issueParam)
    }
  }, [issueParam])

  // Get the selected issue details
  const selectedIssueDetails = selectedIssue ?
    mockIssues.find(issue => issue.id === selectedIssue) : null

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    if (!walletConnected) {
      // Handle wallet connection requirement
      return
    }

    if (!selectedIssue) {
      // Issue selection is required
      return
    }

    setIsSubmitting(true)
    try {
      // TODO: Implement IPFS upload and blockchain submission
      // For now, simulate a successful submission
      await new Promise(resolve => setTimeout(resolve, 2000))
      setIpfsHash("QmTest123...")
      setIsSubmitted(true)
    } catch (error) {
      console.error("Failed to submit perspective:", error)
    } finally {
      setIsSubmitting(false)
    }
  }

  if (!walletConnected) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="mx-auto max-w-3xl text-center">
          <h1 className="text-3xl font-bold tracking-tight sm:text-4xl">Connect Your Wallet</h1>
          <p className="mt-4 text-lg text-muted-foreground">
            Please connect your wallet to submit a perspective.
          </p>
        </div>
      </div>
    )
  }

  if (isSubmitted) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="mx-auto max-w-3xl text-center">
          <div className="mb-4 flex justify-center">
            <CheckCircle className="h-12 w-12 text-green-500" />
          </div>
          <h1 className="text-3xl font-bold tracking-tight sm:text-4xl">Perspective Submitted!</h1>
          <p className="mt-4 text-lg text-muted-foreground">
            Your perspective has been successfully submitted and stored on IPFS.
          </p>
          <p className="mt-2 text-sm text-muted-foreground">
            IPFS Hash: {ipfsHash}
          </p>
          <div className="mt-8 flex flex-col sm:flex-row justify-center gap-4">
            <Button
              variant="outline"
              onClick={() => {
                setIsSubmitted(false)
                setTitle("")
                setContent("")
              }}
            >
              Submit Another Perspective
            </Button>
            {selectedIssue && (
              <Button asChild>
                <Link href={`/issues/${selectedIssue}`}>
                  View Issue
                </Link>
              </Button>
            )}
          </div>
        </div>
      </div>
    )
  }

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mx-auto max-w-3xl">
        {selectedIssue && (
          <Button variant="ghost" size="sm" asChild className="mb-4">
            <Link href={`/issues/${selectedIssue}`}>
              <ArrowLeft className="mr-2 h-4 w-4" />
              Back to Issue
            </Link>
          </Button>
        )}

        <div className="mb-8 text-center">
          <h1 className="text-3xl font-bold tracking-tight sm:text-4xl">Submit Your Perspective</h1>
          <p className="mt-4 text-lg text-muted-foreground">
            Share your thoughts on important issues. Your perspective helps build a better future for everyone.
          </p>
        </div>

        <Card>
          <CardHeader>
            <CardTitle>New Perspective</CardTitle>
            <CardDescription>
              Fill out the form below to submit your perspective. Be specific and constructive in your feedback.
            </CardDescription>
          </CardHeader>
          <CardContent>
            <form onSubmit={handleSubmit} className="space-y-6">
              {/* Issue Selection */}
              <div className="space-y-2">
                <Label htmlFor="issue" className="flex items-center">
                  Select Issue <span className="text-red-500 ml-1">*</span>
                  <span className="text-xs text-muted-foreground ml-2">(Required)</span>
                </Label>

                {selectedIssueDetails ? (
                  <div className="mb-4">
                    <div className="flex items-center justify-between p-3 border rounded-md">
                      <div>
                        <p className="font-medium">{selectedIssueDetails.title}</p>
                        <Badge variant="outline" className="mt-1">{selectedIssueDetails.category}</Badge>
                      </div>
                      <Button
                        type="button"
                        variant="ghost"
                        size="sm"
                        onClick={() => setSelectedIssue(null)}
                      >
                        Change
                      </Button>
                    </div>
                    <p className="text-xs text-muted-foreground mt-2">
                      Your perspective will be linked to this issue
                    </p>
                  </div>
                ) : (
                  <div>
                    <Select
                      value={selectedIssue || ""}
                      onValueChange={(value) => setSelectedIssue(value)}
                      required
                    >
                      <SelectTrigger>
                        <SelectValue placeholder="Choose an issue to respond to" />
                      </SelectTrigger>
                      <SelectContent>
                        {mockIssues.map((issue) => (
                          <SelectItem key={issue.id} value={issue.id}>
                            {issue.title} ({issue.category})
                          </SelectItem>
                        ))}
                      </SelectContent>
                    </Select>

                    <div className="mt-2 flex justify-between items-center">
                      <p className="text-xs text-muted-foreground">
                        Can't find the issue you're looking for?
                      </p>
                      <Button type="button" variant="link" size="sm" asChild className="p-0 h-auto">
                        <Link href="/issues/propose">Propose a new issue</Link>
                      </Button>
                    </div>
                  </div>
                )}
              </div>

              {!selectedIssue && (
                <Alert className="mb-4">
                  <AlertTitle>Note</AlertTitle>
                  <AlertDescription>
                    All perspectives must be linked to a specific issue. This helps organize discussions and generate meaningful insights.
                  </AlertDescription>
                </Alert>
              )}

              {/* Title */}
              <div className="space-y-2">
                <Label htmlFor="title">Title</Label>
                <Input
                  id="title"
                  value={title}
                  onChange={(e) => setTitle(e.target.value)}
                  placeholder="Give your perspective a clear, concise title"
                  className="w-full"
                  required
                />
              </div>

              {/* Content */}
              <div className="space-y-2">
                <Label htmlFor="content">Your Perspective</Label>
                <Textarea
                  id="content"
                  value={content}
                  onChange={(e) => setContent(e.target.value)}
                  placeholder="Share your thoughts in detail. Consider including specific examples or suggestions."
                  className="min-h-[200px]"
                  required
                />
              </div>

              {/* Attachments */}
              <div className="space-y-2">
                <Label>Attachments (Optional)</Label>
                <div className="flex items-center gap-4">
                  <Button type="button" variant="outline" className="gap-2">
                    <Upload className="h-4 w-4" />
                    Upload Files
                  </Button>
                  <p className="text-sm text-muted-foreground">
                    Supported formats: PDF, DOC, DOCX, JPG, PNG (max 10MB)
                  </p>
                </div>
              </div>

              {/* Submit Button */}
              <div className="flex justify-end">
                <Button
                  type="submit"
                  className="gap-2"
                  disabled={isSubmitting || !selectedIssue}
                >
                  {isSubmitting ? (
                    <>
                      <Loader2 className="h-4 w-4 animate-spin" />
                      Submitting...
                    </>
                  ) : (
                    <>
                      <FileText className="h-4 w-4" />
                      Submit Perspective
                    </>
                  )}
                </Button>
              </div>
            </form>
          </CardContent>
        </Card>

        {/* Guidelines */}
        <Card className="mt-8">
          <CardHeader>
            <CardTitle>Submission Guidelines</CardTitle>
            <CardDescription>Tips for submitting an effective perspective</CardDescription>
          </CardHeader>
          <CardContent>
            <ul className="list-disc space-y-2 pl-4 text-muted-foreground">
              <li>Be specific and provide concrete examples</li>
              <li>Focus on constructive solutions rather than just problems</li>
              <li>Consider the impact on different stakeholders</li>
              <li>Support your perspective with data when possible</li>
              <li>Keep your tone professional and respectful</li>
              <li>Review your submission for clarity before posting</li>
            </ul>
          </CardContent>
        </Card>
      </div>
    </div>
  )
}

